@@ -120,70 +120,74 @@ class Command(BaseCommand):
             help="Debug mode. Can see boilerplateMark in html.")
 
     def handle(self, *args, **options):
-        if len(args) < 1:
-            path = TEMPLATES_DIR_PATH
-        else:
-            path = args[0]
+        try:
+            if len(args) < 1:
+                path = TEMPLATES_DIR_PATH
+            else:
+                path = args[0]
 
-        debug = options['debug']
+            debug = options['debug']
 
-        logger.info('Processing...')
+            logger.info('Processing...')
 
-        # static and html file md5 dict ----------------------------------------
-        staticDict = self.buildFileDict('static')
-        staticDict['js/FixTemplate.js'] = \
-            hashlib.md5('js/FixTemplate.js').hexdigest()
-        templateDict = self.buildFileDict('templates')
-        fileDict = dict(staticDict)
-        fileDict.update(templateDict)
-       
-        for root, dirs, files in os.walk(path):
-            for htmlfile in files:
-                name = htmlfile
-                htmlfile = os.path.join(root, htmlfile)
-                logger.info(htmlfile)
+            # static and html file md5 dict ----------------------------------------
+            staticDict = self.buildFileDict('static')
+            staticDict['js/FixTemplate.js'] = \
+                hashlib.md5('js/FixTemplate.js').hexdigest()
+            templateDict = self.buildFileDict('templates')
+            fileDict = dict(staticDict)
+            fileDict.update(templateDict)
+        
+            for root, dirs, files in os.walk(path):
+                for htmlfile in files:
+                    name = htmlfile
+                    htmlfile = os.path.join(root, htmlfile)
+                    logger.info(htmlfile)
 
-                # preprocess ===================================================
-                commentDict = self.findComment(htmlfile)
-                self.replaceExceptTags(htmlfile)
-                
-                # process lxml etree ===========================================
-                with open(htmlfile) as f:
-                    if not f.name.endswith(".html"):
-                        continue
-
-                    # etree ----------------------------------------------------
-                    page = parse(f, beautifulsoup=BeautifulSoup)
+                    # preprocess ===============================================
+                    commentDict = self.findComment(htmlfile)
+                    self.replaceExceptTags(htmlfile)
                     
-                    # replace word
-                    self.changeWordToMd5(page)
+                    # process lxml etree =======================================
+                    with open(htmlfile) as f:
+                        if not f.name.endswith(".html"):
+                            continue
 
-                    # build placeholder
-                    self.buildPlaceholder(page, name, debug=debug)
-                    
-                    # deal with <head> and cms template tag
-                    self.addCMSTags(page)
+                        # etree ------------------------------------------------
+                        page = parse(f, beautifulsoup=BeautifulSoup)
+                        
+                        # replace word
+                        self.changeWordToMd5(page)
 
-                    # deal with file path
-                    self.replaceKeyword(page, fileDict)
+                        # build placeholder
+                        self.buildPlaceholder(page, name, debug=debug)
+                        
+                        # deal with <head> and cms template tag
+                        self.addCMSTags(page)
 
-                    for tag in page.iter(tag='html'):
-                        html = tag
-                    self.indent(html)
+                        # deal with file path
+                        self.replaceKeyword(page, fileDict)
 
-                    # write file
-                    page.write(htmlfile, method='html', pretty_print=True)
+                        for tag in page.iter(tag='html'):
+                            html = tag
+                        self.indent(html)
 
-                # endprocess ===================================================
-                self.fixStaticTemplate(htmlfile, fileDict)
-                self.fixComment(htmlfile, commentDict)
-                self.changeMd5ToWord(htmlfile)
-                self.fixExceptTags(htmlfile)
+                        # write file
+                        page.write(htmlfile, method='html', pretty_print=True)
 
-                logger.info(htmlfile + " is OK!")
+                    # endprocess ===============================================
+                    self.fixStaticTemplate(htmlfile, fileDict)
+                    self.fixComment(htmlfile, commentDict)
+                    self.changeMd5ToWord(htmlfile)
+                    self.fixExceptTags(htmlfile)
 
-        logger.info('ALL OK!')
+                    logger.info(htmlfile + " is OK!")
 
+            logger.info('ALL OK!')
+        except Exception as e:
+            logger.error("build_boilerplate2 error:%s" % e)
+            raise
+            
     #---------------------------------Main--------------------------------------
     def buildPlaceholder(self, eTree, filename, debug=False):
         index = filename.index('.html')
