@@ -62,6 +62,14 @@ class Command(BaseCommand):
             with open(os.path.join(machinePath, 'BuildTemplates.log')) as log:
                 content = log.read()
             if content:
+                for f in os.listdir(machinePath):
+                    if f == 'BuildTemplates.log':
+                        continue
+                    if f.endswith('.log'):
+                        with open(os.path.join(machinePath, f)) as log:
+                            content += log.read()
+
+                content = content.strip().replace('\n', '|')
                 logger.error(content)
                 return 1
             else:
