@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 10574 2017-11-29 03:26:17Z Lavender $
+# $Id: setup.py 10579 2017-11-29 06:00:34Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-11-29 11:26:17 +0800 (週三, 29 十一月 2017) $
-# $Revision: 10574 $ 
+# $Date: 2017-11-29 14:00:34 +0800 (週三, 29 十一月 2017) $
+# $Revision: 10579 $ 
 
 import os
 import sys
@@ -349,24 +349,28 @@ if __name__ == "__main__":
                     " \"python manage.py runserver\" to start your project" % 
                     path)
 
-    {% if upc %}
-    tid = 'UA-110201703-1'
-    cid = '{{ upc }}'
-    ec = "Product"
-    ea = "Setup"
-    el = "upc={{ upc }}"
-    url = ("https://www.google-analytics.com/collect?"
-           "v=1&t=event&tid=%s&cid=%s&ec=%s&ea=%s&el=%s&ev=300" % (
-               tid, cid, ec, ea, el))
     try:
-        if sys.version_info.major == 3:
-            import urllib.request
-            result = urllib.request.urlopen(url)
-        else:
-            import urllib2
-            result = urllib2.urlopen(url)
+        import json
+
+        if os.path.isfile(os.path.join(SETUP_DIR, 'MANIFAST.INFO')):
+            with open(os.path.join(SETUP_DIR, 'MANIFAST.INFO')) as f:
+                data = json.loads(f.read())
+            tid = 'UA-110201703-1'
+            cid = data['upc']
+            ec = "Product"
+            ea = "Setup"
+            el = "upc=%s" % data['upc']
+            url = ("https://www.google-analytics.com/collect?"
+                    "v=1&t=event&tid=%s&cid=%s&ec=%s&ea=%s&el=%s&ev=300" % (
+                        tid, cid, ec, ea, el))
+            if sys.version_info.major == 3:
+                import urllib.request
+                result = urllib.request.urlopen(url)
+            else:
+                import urllib2
+                result = urllib2.urlopen(url)
     except Exception as e:
         pass
-    {% endif %}
+
     
     
\ No newline at end of file
